@@ -1,13 +1,17 @@
+from types import TracebackType
 from typing import (
+    Type,
     Any,
     MutableMapping,
     Callable,
     Iterable,
     Tuple,
-    AnyStr,
     Awaitable,
+    Optional,
 )
 
+ExcInfo = Tuple[Type[BaseException], BaseException, Optional[TracebackType]]
+
 Message = MutableMapping[str, Any]
 
 Scope = MutableMapping[str, Any]
@@ -20,6 +24,6 @@ ASGIApp = Callable[[Scope, Receive, Send], Awaitable[None]]
 
 Environ = MutableMapping[str, Any]
 
-StartResponse = Callable[[str, Iterable[Tuple[str, str]]], None]
+StartResponse = Callable[[str, Iterable[Tuple[str, str]], Optional[ExcInfo]], None]
 
-WSGIApp = Callable[[Environ, StartResponse], Iterable[AnyStr]]
+WSGIApp = Callable[[Environ, StartResponse], Iterable[bytes]]
